==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/RelationshipattributeRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Relationshipattribute;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.MailboxtrackingfolderCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class RelationshipattributeRequest extends EntityRequest<Relationshipattribute> {

    public RelationshipattributeRequest(ContextPath contextPath, Optional<Object> value) {
        super(Relationshipattribute.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public SyncerrorCollectionRequest relationshipattribute_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("relationshipattribute_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest relationshipattribute_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("relationshipattribute_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest relationshipattribute_AsyncOperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("relationshipattribute_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest relationshipattribute_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("relationshipattribute_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest relationshipattribute_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(
                        contextPath.addSegment("relationshipattribute_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest relationshipattribute_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("relationshipattribute_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest relationshipattribute_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("relationshipattribute_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest relationshipattribute_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("relationshipattribute_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest relationshipattribute_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("relationshipattribute_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest relationshipattribute_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("relationshipattribute_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public AttributeRequest referencingattributeid_relationshipattribute() {
        return new AttributeRequest(contextPath.addSegment("referencingattributeid_relationshipattribute"), Optional.empty());
    }

    public AttributeRequest referencedattributeid_relationshipattribute() {
        return new AttributeRequest(contextPath.addSegment("referencedattributeid_relationshipattribute"), Optional.empty());
    }

    public RelationshipRequest relationshipid_relationshipattribute() {
        return new RelationshipRequest(contextPath.addSegment("relationshipid_relationshipattribute"), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.45-sources.jar: microsoft/dynamics/crm/entity/request/RelationshipattributeRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Relationshipattribute;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.MailboxtrackingfolderCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;

@JsonIgnoreType
public class RelationshipattributeRequest extends EntityRequest<Relationshipattribute> {

    public RelationshipattributeRequest(ContextPath contextPath, Optional<Object> value) {
        super(Relationshipattribute.class, contextPath, value);
    }

    public SyncerrorCollectionRequest relationshipattribute_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("relationshipattribute_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest relationshipattribute_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("relationshipattribute_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest relationshipattribute_AsyncOperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("relationshipattribute_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest relationshipattribute_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("relationshipattribute_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest relationshipattribute_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(
                        contextPath.addSegment("relationshipattribute_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest relationshipattribute_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("relationshipattribute_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest relationshipattribute_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("relationshipattribute_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest relationshipattribute_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("relationshipattribute_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest relationshipattribute_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("relationshipattribute_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest relationshipattribute_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("relationshipattribute_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public AttributeRequest referencingattributeid_relationshipattribute() {
        return new AttributeRequest(contextPath.addSegment("referencingattributeid_relationshipattribute"), Optional.empty());
    }

    public AttributeRequest referencedattributeid_relationshipattribute() {
        return new AttributeRequest(contextPath.addSegment("referencedattributeid_relationshipattribute"), Optional.empty());
    }

    public RelationshipRequest relationshipid_relationshipattribute() {
        return new RelationshipRequest(contextPath.addSegment("relationshipid_relationshipattribute"), Optional.empty());
    }

}
